@@ -4,6 +4,7 @@ from tweetcapture.utils.utils import is_valid_tweet_url, get_tweet_file_name
 from selenium.webdriver.common.by import By
 from PIL import Image
 from os import remove
+from os.path import exists
 
 class TweetCapture:
     driver = None
@@ -15,20 +16,27 @@ class TweetCapture:
     lang = None
     test = False
     show_parent_tweets = False
+    show_mentions_count = 0
+    overwrite = False
 
-    def __init__(self, mode=3, night_mode=0, test=False, show_parent_tweets=False):
+    def __init__(self, mode=3, night_mode=0, test=False, show_parent_tweets=False, show_mentions_count=0, overwrite=False):
         self.set_night_mode(night_mode)
         self.set_mode(mode)
         self.test = test
         self.show_parent_tweets = show_parent_tweets
+        self.show_mentions_count = show_mentions_count
+        self.overwrite = overwrite
 
-    async def screenshot(self, url, path=None, mode=None, night_mode=None, show_parent_tweets=None):
+    async def screenshot(self, url, path=None, mode=None, night_mode=None, show_parent_tweets=None, show_mentions_count=None, overwrite=None):
         if is_valid_tweet_url(url) is False:
             raise Exception("Invalid tweet url")
 
         if not isinstance(path, str) or len(path) == 0:
             path = get_tweet_file_name(url)
 
+        if exists(path) and (self.overwrite if overwrite is None else overwrite) is False:
+            raise Exception("File already exists")
+
         url = is_valid_tweet_url(url)
         if self.lang:
             url += "?lang=" + self.lang
@@ -46,7 +54,7 @@ class TweetCapture:
 
             if self.test is True: driver.save_screenshot("web.png")
             await sleep(1.0)
-            elements, main = self.__get_tweets(driver, self.show_parent_tweets if show_parent_tweets is None else show_parent_tweets)
+            elements, main = self.__get_tweets(driver, self.show_parent_tweets if show_parent_tweets is None else show_parent_tweets, self.show_mentions_count if show_mentions_count is None else show_mentions_count)
             if len(elements) == 0:
                 raise Exception("Tweets not found")
             else:
@@ -210,7 +218,7 @@ class TweetCapture:
         """
 
     # Return: (elements, main_element_index)
-    def __get_tweets(self, driver, show_parents):
+    def __get_tweets(self, driver, show_parents, show_mentions_count):
         elements = driver.find_elements(By.XPATH, "(//ancestor::article)/..")
         length = len(elements)
         if length > 0:
@@ -226,10 +234,21 @@ class TweetCapture:
                 if main_element == -1:
                     return [], -1
                 else:
-                    if show_parents and main_element != 0:
-                        for i, element in enumerate(elements[0:main_element+1]):
-                            driver.execute_script("""console.log(arguments[0])""", element)
-                        return elements[0:main_element+1], main_element
+                    r = main_element+1
+                    r2 = r+show_mentions_count
+                    if show_parents and show_mentions_count > 0:
+                        if len(elements[r:]) > show_mentions_count:                   
+                            return (elements[0:r] + elements[r:r2]), main_element
+                        return elements, main_element
+                    elif show_parents:
+                        if main_element == 0:
+                            return elements[0:1], 0
+                        else:
+                            return elements[:r], main_element
+                    elif show_mentions_count > 0:
+                        if len(elements[r:]) > show_mentions_count:
+                            return elements[main_element:1] + elements[r:r2], 0
+                        return elements[main_element:], 0
                     else:
-                        return elements[0:1], main_element
+                        return elements[main_element:r], main_element
         return [], -1
\ No newline at end of file
